==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/entity/Trending.java <==
package odata.msgraph.client.beta.entity;

import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ClientException;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.ODataEntityType;
import com.github.davidmoten.odata.client.RequestOptions;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.NavigationProperty;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.UnmappedFields;

import java.time.OffsetDateTime;
import java.util.Optional;

import odata.msgraph.client.beta.complex.ResourceReference;
import odata.msgraph.client.beta.complex.ResourceVisualization;
import odata.msgraph.client.beta.entity.request.EntityRequest;

@JsonPropertyOrder({
    "@odata.type", 
    "weight", 
    "resourceVisualization", 
    "resourceReference", 
    "lastModifiedDateTime"})
@JsonInclude(Include.NON_NULL)
public class Trending extends Entity implements ODataEntityType {

    @Override
    public String odataTypeName() {
        return "microsoft.graph.trending";
    }

    @JsonProperty("weight")
    protected Double weight;

    @JsonProperty("resourceVisualization")
    protected ResourceVisualization resourceVisualization;

    @JsonProperty("resourceReference")
    protected ResourceReference resourceReference;

    @JsonProperty("lastModifiedDateTime")
    protected OffsetDateTime lastModifiedDateTime;

    protected Trending() {
        super();
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderTrending() {
        return new Builder();
    }

    public static final class Builder {
        private String id;
        private Double weight;
        private ResourceVisualization resourceVisualization;
        private ResourceReference resourceReference;
        private OffsetDateTime lastModifiedDateTime;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder id(String id) {
            this.id = id;
            this.changedFields = changedFields.add("id");
            return this;
        }

        public Builder weight(Double weight) {
            this.weight = weight;
            this.changedFields = changedFields.add("weight");
            return this;
        }

        /**
         * <p>
         * <b>Org.OData.Core.V1.Computed</b>
         * <p>
         * true
         * 
         * @param resourceVisualization
         *            value of {@code resourceVisualization} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder resourceVisualization(ResourceVisualization resourceVisualization) {
            this.resourceVisualization = resourceVisualization;
            this.changedFields = changedFields.add("resourceVisualization");
            return this;
        }

        /**
         * <p>
         * <b>Org.OData.Core.V1.Computed</b>
         * <p>
         * true
         * 
         * @param resourceReference
         *            value of {@code resourceReference} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder resourceReference(ResourceReference resourceReference) {
            this.resourceReference = resourceReference;
            this.changedFields = changedFields.add("resourceReference");
            return this;
        }

        public Builder lastModifiedDateTime(OffsetDateTime lastModifiedDateTime) {
            this.lastModifiedDateTime = lastModifiedDateTime;
            this.changedFields = changedFields.add("lastModifiedDateTime");
            return this;
        }

        public Trending build() {
            Trending _x = new Trending();
            _x.contextPath = null;
            _x.changedFields = changedFields;
            _x.unmappedFields = new UnmappedFields();
            _x.odataType = "microsoft.graph.trending";
            _x.id = id;
            _x.weight = weight;
            _x.resourceVisualization = resourceVisualization;
            _x.resourceReference = resourceReference;
            _x.lastModifiedDateTime = lastModifiedDateTime;
            return _x;
        }
    }

    @Override
    @JsonIgnore
    public ChangedFields getChangedFields() {
        return changedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        if (addKeysToContextPath && id != null) {
            contextPath = contextPath.clearQueries().addKeys(new NameValue(id.toString()));
        }
    }

    @Property(name="weight")
    @JsonIgnore
    public Optional<Double> getWeight() {
        return Optional.ofNullable(weight);
    }

    public Trending withWeight(Double weight) {
        Trending _x = _copy();
        _x.changedFields = changedFields.add("weight");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.trending");
        _x.weight = weight;
        return _x;
    }

    /**
     * <p>
     * <b>Org.OData.Core.V1.Computed</b>
     * <p>
     * true
     * 
     * @return property resourceVisualization
     */
    @Property(name="resourceVisualization")
    @JsonIgnore
    public Optional<ResourceVisualization> getResourceVisualization() {
        return Optional.ofNullable(resourceVisualization);
    }

    /**
     * Returns an immutable copy of {@code this} with just the {@code
     * resourceVisualization} field changed. Field description below. The field name is
     * also added to an internal map of changed fields in the returned object so that
     * when {@code this.patch()} is called (if available)on the returned object only
     * the changed fields are submitted.
     * <p>
     * <b>Org.OData.Core.V1.Computed</b>
     * <p>
     * true
     * 
     * @param resourceVisualization
     *            new value of {@code resourceVisualization} field (as defined in service metadata)
     * @return immutable copy of {@code this} with just the {@code resourceVisualization} field changed
     */
    public Trending withResourceVisualization(ResourceVisualization resourceVisualization) {
        Trending _x = _copy();
        _x.changedFields = changedFields.add("resourceVisualization");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.trending");
        _x.resourceVisualization = resourceVisualization;
        return _x;
    }

    /**
     * <p>
     * <b>Org.OData.Core.V1.Computed</b>
     * <p>
     * true
     * 
     * @return property resourceReference
     */
    @Property(name="resourceReference")
    @JsonIgnore
    public Optional<ResourceReference> getResourceReference() {
        return Optional.ofNullable(resourceReference);
    }

    /**
     * Returns an immutable copy of {@code this} with just the {@code resourceReference
     * } field changed. Field description below. The field name is also added to an
     * internal map of changed fields in the returned object so that when {@code this.
     * patch()} is called (if available)on the returned object only the changed fields
     * are submitted.
     * <p>
     * <b>Org.OData.Core.V1.Computed</b>
     * <p>
     * true
     * 
     * @param resourceReference
     *            new value of {@code resourceReference} field (as defined in service metadata)
     * @return immutable copy of {@code this} with just the {@code resourceReference} field changed
     */
    public Trending withResourceReference(ResourceReference resourceReference) {
        Trending _x = _copy();
        _x.changedFields = changedFields.add("resourceReference");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.trending");
        _x.resourceReference = resourceReference;
        return _x;
    }

    @Property(name="lastModifiedDateTime")
    @JsonIgnore
    public Optional<OffsetDateTime> getLastModifiedDateTime() {
        return Optional.ofNullable(lastModifiedDateTime);
    }

    public Trending withLastModifiedDateTime(OffsetDateTime lastModifiedDateTime) {
        Trending _x = _copy();
        _x.changedFields = changedFields.add("lastModifiedDateTime");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.trending");
        _x.lastModifiedDateTime = lastModifiedDateTime;
        return _x;
    }

    @NavigationProperty(name="resource")
    @JsonIgnore
    public EntityRequest getResource() {
        return new EntityRequest(contextPath.addSegment("resource"));
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFields();
        }
        unmappedFields.put(name, value);
    }

    @Override
    @JsonIgnore
    public UnmappedFields getUnmappedFields() {
        return unmappedFields == null ? new UnmappedFields() : unmappedFields;
    }

    /**
     * Submits only changed fields for update and returns an 
     * immutable copy of {@code this} with changed fields reset.
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public Trending patch() {
        RequestHelper.patch(this, contextPath, RequestOptions.EMPTY);
        Trending _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    /**
     * Submits all fields for update and returns an immutable copy of {@code this}
     * with changed fields reset (they were ignored anyway).
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public Trending put() {
        RequestHelper.put(this, contextPath, RequestOptions.EMPTY);
        Trending _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    private Trending _copy() {
        Trending _x = new Trending();
        _x.contextPath = contextPath;
        _x.changedFields = changedFields;
        _x.unmappedFields = unmappedFields;
        _x.odataType = odataType;
        _x.id = id;
        _x.weight = weight;
        _x.resourceVisualization = resourceVisualization;
        _x.resourceReference = resourceReference;
        _x.lastModifiedDateTime = lastModifiedDateTime;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("Trending[");
        b.append("id=");
        b.append(this.id);
        b.append(", ");
        b.append("weight=");
        b.append(this.weight);
        b.append(", ");
        b.append("resourceVisualization=");
        b.append(this.resourceVisualization);
        b.append(", ");
        b.append("resourceReference=");
        b.append(this.resourceReference);
        b.append(", ");
        b.append("lastModifiedDateTime=");
        b.append(this.lastModifiedDateTime);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }
}

==> odata-client-msgraph-beta-0.2.2-sources.jar: odata/msgraph/client/beta/entity/Trending.java <==
package odata.msgraph.client.beta.entity;

import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ClientException;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.ODataEntityType;
import com.github.davidmoten.odata.client.RequestOptions;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.NavigationProperty;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Double;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.time.OffsetDateTime;
import java.util.Optional;

import odata.msgraph.client.beta.complex.ResourceReference;
import odata.msgraph.client.beta.complex.ResourceVisualization;
import odata.msgraph.client.beta.entity.request.EntityRequest;

@JsonPropertyOrder({
    "@odata.type", 
    "lastModifiedDateTime", 
    "resourceReference", 
    "resourceVisualization", 
    "weight"})
@JsonInclude(Include.NON_NULL)
public class Trending extends Entity implements ODataEntityType {

    @Override
    public String odataTypeName() {
        return "microsoft.graph.trending";
    }

    @JsonProperty("lastModifiedDateTime")
    protected OffsetDateTime lastModifiedDateTime;

    @JsonProperty("resourceReference")
    protected ResourceReference resourceReference;

    @JsonProperty("resourceVisualization")
    protected ResourceVisualization resourceVisualization;

    @JsonProperty("weight")
    protected Double weight;

    protected Trending() {
        super();
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderTrending() {
        return new Builder();
    }

    public static final class Builder {
        private String id;
        private OffsetDateTime lastModifiedDateTime;
        private ResourceReference resourceReference;
        private ResourceVisualization resourceVisualization;
        private Double weight;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder id(String id) {
            this.id = id;
            this.changedFields = changedFields.add("id");
            return this;
        }

        public Builder lastModifiedDateTime(OffsetDateTime lastModifiedDateTime) {
            this.lastModifiedDateTime = lastModifiedDateTime;
            this.changedFields = changedFields.add("lastModifiedDateTime");
            return this;
        }

        /**
         * <p>
         * <b>Org.OData.Core.V1.Computed</b>
         * <p>
         * true
         * 
         * @param resourceReference
         *            value of {@code resourceReference} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder resourceReference(ResourceReference resourceReference) {
            this.resourceReference = resourceReference;
            this.changedFields = changedFields.add("resourceReference");
            return this;
        }

        /**
         * <p>
         * <b>Org.OData.Core.V1.Computed</b>
         * <p>
         * true
         * 
         * @param resourceVisualization
         *            value of {@code resourceVisualization} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder resourceVisualization(ResourceVisualization resourceVisualization) {
            this.resourceVisualization = resourceVisualization;
            this.changedFields = changedFields.add("resourceVisualization");
            return this;
        }

        public Builder weight(Double weight) {
            this.weight = weight;
            this.changedFields = changedFields.add("weight");
            return this;
        }

        public Trending build() {
            Trending _x = new Trending();
            _x.contextPath = null;
            _x.changedFields = changedFields;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "microsoft.graph.trending";
            _x.id = id;
            _x.lastModifiedDateTime = lastModifiedDateTime;
            _x.resourceReference = resourceReference;
            _x.resourceVisualization = resourceVisualization;
            _x.weight = weight;
            return _x;
        }
    }

    @Override
    @JsonIgnore
    public ChangedFields getChangedFields() {
        return changedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        if (addKeysToContextPath && id != null) {
            contextPath = contextPath.clearQueries().addKeys(new NameValue(id, String.class));
        }
    }

    @Property(name="lastModifiedDateTime")
    @JsonIgnore
    public Optional<OffsetDateTime> getLastModifiedDateTime() {
        return Optional.ofNullable(lastModifiedDateTime);
    }

    public Trending withLastModifiedDateTime(OffsetDateTime lastModifiedDateTime) {
        Trending _x = _copy();
        _x.changedFields = changedFields.add("lastModifiedDateTime");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.trending");
        _x.lastModifiedDateTime = lastModifiedDateTime;
        return _x;
    }

    /**
     * <p>
     * <b>Org.OData.Core.V1.Computed</b>
     * <p>
     * true
     * 
     * @return property resourceReference
     */
    @Property(name="resourceReference")
    @JsonIgnore
    public Optional<ResourceReference> getResourceReference() {
        return Optional.ofNullable(resourceReference);
    }

    /**
     * Returns an immutable copy of {@code this} with just the {@code resourceReference
     * } field changed. Field description below. The field name is also added to an
     * internal map of changed fields in the returned object so that when {@code this.
     * patch()} is called (if available)on the returned object only the changed fields
     * are submitted.
     * <p>
     * <b>Org.OData.Core.V1.Computed</b>
     * <p>
     * true
     * 
     * @param resourceReference
     *            new value of {@code resourceReference} field (as defined in service metadata)
     * @return immutable copy of {@code this} with just the {@code resourceReference} field changed
     */
    public Trending withResourceReference(ResourceReference resourceReference) {
        Trending _x = _copy();
        _x.changedFields = changedFields.add("resourceReference");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.trending");
        _x.resourceReference = resourceReference;
        return _x;
    }

    /**
     * <p>
     * <b>Org.OData.Core.V1.Computed</b>
     * <p>
     * true
     * 
     * @return property resourceVisualization
     */
    @Property(name="resourceVisualization")
    @JsonIgnore
    public Optional<ResourceVisualization> getResourceVisualization() {
        return Optional.ofNullable(resourceVisualization);
    }

    /**
     * Returns an immutable copy of {@code this} with just the {@code
     * resourceVisualization} field changed. Field description below. The field name is
     * also added to an internal map of changed fields in the returned object so that
     * when {@code this.patch()} is called (if available)on the returned object only
     * the changed fields are submitted.
     * <p>
     * <b>Org.OData.Core.V1.Computed</b>
     * <p>
     * true
     * 
     * @param resourceVisualization
     *            new value of {@code resourceVisualization} field (as defined in service metadata)
     * @return immutable copy of {@code this} with just the {@code resourceVisualization} field changed
     */
    public Trending withResourceVisualization(ResourceVisualization resourceVisualization) {
        Trending _x = _copy();
        _x.changedFields = changedFields.add("resourceVisualization");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.trending");
        _x.resourceVisualization = resourceVisualization;
        return _x;
    }

    @Property(name="weight")
    @JsonIgnore
    public Optional<Double> getWeight() {
        return Optional.ofNullable(weight);
    }

    public Trending withWeight(Double weight) {
        Trending _x = _copy();
        _x.changedFields = changedFields.add("weight");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.trending");
        _x.weight = weight;
        return _x;
    }

    public Trending withUnmappedField(String name, Object value) {
        Trending _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @NavigationProperty(name="resource")
    @JsonIgnore
    public EntityRequest getResource() {
        return new EntityRequest(contextPath.addSegment("resource"), RequestHelper.getValue(unmappedFields, "resource"));
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    /**
     * Submits only changed fields for update and returns an 
     * immutable copy of {@code this} with changed fields reset.
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public Trending patch() {
        RequestHelper.patch(this, contextPath, RequestOptions.EMPTY);
        Trending _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    /**
     * Submits all fields for update and returns an immutable copy of {@code this}
     * with changed fields reset (they were ignored anyway).
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public Trending put() {
        RequestHelper.put(this, contextPath, RequestOptions.EMPTY);
        Trending _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    private Trending _copy() {
        Trending _x = new Trending();
        _x.contextPath = contextPath;
        _x.changedFields = changedFields;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.id = id;
        _x.lastModifiedDateTime = lastModifiedDateTime;
        _x.resourceReference = resourceReference;
        _x.resourceVisualization = resourceVisualization;
        _x.weight = weight;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("Trending[");
        b.append("id=");
        b.append(this.id);
        b.append(", ");
        b.append("lastModifiedDateTime=");
        b.append(this.lastModifiedDateTime);
        b.append(", ");
        b.append("resourceReference=");
        b.append(this.resourceReference);
        b.append(", ");
        b.append("resourceVisualization=");
        b.append(this.resourceVisualization);
        b.append(", ");
        b.append("weight=");
        b.append(this.weight);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }
}
